==> haskell-distributive-0.6-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-GG50drgnUvrA8VTISpGDag
key: distributive-0.6-GG50drgnUvrA8VTISpGDag
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: 01d11b1aeedafa2f551f3d76001738af
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/distributive-0.6
hs-libraries: HSdistributive-0.6-GG50drgnUvrA8VTISpGDag
depends:
    base-4.12.0.0 base-orphans-0.8.1-1eiH9qVb6AAEHB9dzgavFy
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-distributive-0.6-31-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-distributive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: distributive
version: 0.6
id: distributive-0.6-46i0ICRb7I89PMCNGFAS12
key: distributive-0.6-46i0ICRb7I89PMCNGFAS12
license: BSD-3-Clause
copyright: Copyright (C) 2011-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/distributive/
synopsis: Distributive functors -- Dual to Traversable
description:
    Distributive functors -- Dual to @Traversable@
category: Data Structures
abi: 568c4e0432238ce6ce40ca6505dddd24
exposed: True
exposed-modules:
    Data.Distributive Data.Distributive.Generic
import-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6
library-dirs: /usr/lib/ghc-8.6.5/site-local/distributive-0.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/distributive-0.6
hs-libraries: HSdistributive-0.6-46i0ICRb7I89PMCNGFAS12
depends:
    base-4.12.0.0 base-orphans-0.8.1-HeyTAcy4PKhDcGhjvJwDzq
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP transformers-0.5.6.2
haddock-interfaces: /usr/share/doc/haskell-distributive/html/distributive.haddock
haddock-html: /usr/share/doc/haskell-distributive/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
